@@ -21,17 +21,9 @@
 #ifndef EXERCISEFACTORIZE_H
 #define EXERCISEFACTORIZE_H
 
-#ifdef DEBUG
-#include <kdebug.h>
-#endif
-
-#include <qvariant.h>
-#include <qwidget.h>
-#include <QLabel>
 #include <QList>
-#include <QVBoxLayout>
-#include <QHBoxLayout>
-#include <QGridLayout>
+#include <QVariant>
+#include <QWidget>
 
 #include "ExerciseBase.h"
 #include "ResultWidget.h"
@@ -39,13 +31,9 @@
 #include "PrimeFactorsLineEdit.h"
 
 class ResultWidget;
-class QVBoxLayout;
-class QHBoxLayout;
 class QGridLayout;
-class QSpacerItem;
 class QLabel;
 class QPushButton;
-class QToolButton;
 
 // a list containing uints
 typedef QList<uint> uintList;
@@ -77,10 +65,9 @@ public:
     /** force the creation of a new task */
     void forceNewTask();
 
-public slots:
     void update();
 
-signals:
+Q_SIGNALS:
     /** class emits this signal, if the task was solved correctly by the user */
     void signalExerciseSolvedCorrect();
 
@@ -138,13 +125,7 @@ private:
     void addFactor(uint factor);
     void updateEnteredEdit();
 
-
-protected:
-    void showEvent(QShowEvent * event);
-
-
-private slots:
-    void slotFactorsEditReturnPressed(const QString &);
+    void slotFactorsEditReturnPressed();
 
     void slotCheckButtonClicked();
     void slotSkipButtonClicked();
@@ -161,6 +142,9 @@ private slots:
 
     void editContentChanged(bool correct);
     void setButtonsEnabled(bool enabled);
+
+    protected:
+    void showEvent(QShowEvent * event);
 };
 
 #endif
