@@ -21,17 +21,13 @@
 #ifndef EXERCISEMIXEDNUMBERS_H
 #define EXERCISEMIXEDNUMBERS_H
 
-#ifdef DEBUG
-#include <kdebug.h>
-#endif
-
 #include "ExerciseBase.h"
 #include "ResultWidget.h"
 #include "Task.h"
 #include "TaskWidget.h"
 
 
-class KLineEdit;
+class QLineEdit;
 class QFrame;
 class QGridLayout;
 class QPushButton;
@@ -58,7 +54,7 @@ public:
      * after changing the task parameters */
     void forceNewTask();
 
-signals:
+Q_SIGNALS:
     /** signal emitted if task solved correctly */
     void signalExerciseSolvedCorrect();
 
@@ -79,10 +75,10 @@ private:
     Task m_task;
 
     // components to enter result
-    KLineEdit * m_integerEdit;
-    KLineEdit * m_numerEdit;
+    QLineEdit * m_integerEdit;
+    QLineEdit * m_numerEdit;
     QFrame * m_editLine;
-    KLineEdit * m_denoEdit;
+    QLineEdit * m_denoEdit;
 
     // check and skip buttons
     QPushButton * m_checkButton;
@@ -110,11 +106,6 @@ private:
     /** checks result and shows solution */
     void showResult();
 
-protected:
-    /** sets focus to input fields */
-    void showEvent(QShowEvent * event);
-
-private slots:
     /** handle check button click */
     void slotCheckButtonClicked();
 
@@ -122,13 +113,17 @@ private slots:
     void slotSkipButtonClicked();
 
     /** focus set to numerator edit if return pressed in integer edit */
-    void integerReturnPressed(const QString &);
+    void integerReturnPressed();
 
     /** focus set to denominator edit if return pressed in numerator edit */
-    void numerReturnPressed(const QString &);
+    void numerReturnPressed();
 
     /** invokes check button if return pressed in denominator edit */
-    void denoReturnPressed(const QString &);
+    void denoReturnPressed();
+
+    protected:
+    /** sets focus to input fields */
+    void showEvent(QShowEvent * event);
 };
 
 #endif // EXERCISEMIXEDNUMBERS_H
