@@ -21,12 +21,7 @@
 #ifndef PRIMEFACTORSLINEEDIT_H
 #define PRIMEFACTORSLINEEDIT_H
 
-#ifdef DEBUG
-#include <kdebug.h>
-#endif
-
-#include "klineedit.h"
-
+#include <QLineEdit>
 #include <QKeyEvent>
 
 class QString;
@@ -37,7 +32,7 @@ class QString;
  *
  * \author Sebastian Stein
  */
-class PrimeFactorsLineEdit : public KLineEdit
+class PrimeFactorsLineEdit : public QLineEdit
 {
     Q_OBJECT
 
@@ -51,12 +46,11 @@ public:
     /** return the factors entered */
     QStringList getFactors() const;
 
-public slots:
-    /** called when the text in KLineEdit's content changes */
+    /** called when the text in QLineEdit's content changes */
     void textHasChanged(QString text);
 
-signals:
-    /** emitted when KLineEdit's content changes and it's correct
+Q_SIGNALS:
+    /** emitted when QLineEdit's content changes and it's correct
         itIs is true if the content is correct otherwise.
      */
     void contentIsRight(bool itIs);
@@ -65,10 +59,10 @@ private:
     /** will content the factor the application will used:
       * 2, 3, 5, 7, 11, 13, 17, 19 */
     QStringList m_usedFactors;
-    /** the factors entered in the KLineEdit */
+    /** the factors entered in the QLineEdit */
     QStringList m_theFactors;
 
-    /** will check if the KLineEdit's content is right */
+    /** will check if the QLineEdit's content is right */
     bool checkCorrectness(const QString &text);
     /** will check if every factors' element is actually a factor */
     bool areFactors(const QStringList &factors);
